@@ -3,18 +3,18 @@ use std::fmt;
 use super::method::Method;
 use super::request::Request;
 use super::response::Response;
+use crate::path::Path;
 
 /// Defines a route.
 ///
 /// You should not use this directly.
 /// It will be created automatically when using server.route
-// #[derive(Clone)]
 pub struct Route {
     /// Route Method (GET, POST, ANY, etc)
     pub method: Method,
 
     /// Route Path
-    pub path: String,
+    pub path: Path,
 
     /// Route Handler
     pub handler: Box<dyn Fn(Request) -> Response>,
@@ -22,19 +22,10 @@ pub struct Route {
 
 impl Route {
     /// Creates a new route.
-    pub(super) fn new(
-        method: Method,
-        path: String,
-        handler: Box<dyn Fn(Request) -> Response>,
-    ) -> Route {
-        let mut path = path;
-        if path.chars().last().unwrap_or_default() == '/' {
-            path.pop();
-        }
-
+    pub fn new(method: Method, path: String, handler: Box<dyn Fn(Request) -> Response>) -> Route {
         Route {
             method,
-            path,
+            path: Path::new(path),
             handler,
         }
     }
